@@ -705,9 +705,9 @@ def _check_for_upgrade():
 
 def opereto_test(arguments):
 
-    pytest_params = ['-v', '-s', '--show-capture=no', '--tb=no']
+    pytest_params = '-v -s --show-capture=no --tb=no'
     if arguments['--verbose']:
-        pytest_params = ['-v', '-s']
+        pytest_params = '-v -s'
 
     os.environ['OPERETO_TEST_BENCHMAR_TESTPLAN_PID'] = ''
     tid = arguments['--testplan_pid']
@@ -719,13 +719,11 @@ def opereto_test(arguments):
         if not importlib.util.find_spec(package):
             raise Exception(
                 f'Opereto test command requires the following python packages {str(required_packages)}. Please install them and then re-run this command.')
-
-    import pytest
-
     try:
         print('Running Opereto benchmark test (may take a few minutes)...')
         startdate = datetime.utcnow() - timedelta(hours=1)
-        pytest.main(pytest_params)
+        pytest_params.append("--pyargs=pyopereto.tests")
+        os.system(f'pytest --pyargs pyopereto.tests {pytest_params}')
 
         ## run diagnostics
         enddate = datetime.utcnow()
